#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Small program to sort files according to the configuration
you provide. It can be any kind of command to run on your pc.
"""

import argparse
import subprocess
from pathlib import Path
from typing import Any, Dict

from prettyfi.config import SorterConfig
from prettyfi.exceptions import CommandNotFound, UnknownRuleFormat


def parse_args() -> Dict[str, Any]:
    """
    parse command line arguments.
    """
    parser = argparse.ArgumentParser(
        description="Simple utility to make your files prettier."
    )
    parser.add_argument(
        "-c",
        "--config",
        type=Path,
        dest="config",
        default=None,
        help="path to configuration file",
    )
    parser.add_argument("files", type=Path, nargs="+", help="Files to sort")

    return {
        key: val for key, val in parser.parse_args().__dict__.items() if val is not None
    }


def sort_file(file: Path, rule: str) -> None:
    """
    Actually call the command on file.
    """
    try:
        subprocess.call(rule.format(file=str(file)), shell=True)
    except FileNotFoundError as exc:
        raise CommandNotFound(rule) from exc


def main() -> None:
    """
    Program entrypoint.
    """
    args = parse_args()
    sorter_conf = SorterConfig(**args)
    try:
        sorter_conf.startup_actions()
        for file in args["files"]:
            if rule := sorter_conf.get_rule(file.name):
                sort_file(file, rule)
            else:
                print(f"I don't know what to do with {file.name}")
    except UnknownRuleFormat as exception:
        print("Unknown rule format on line " f"{exception.line_num}: {exception.line}")
        print("Rule format is:")
        print('\t.ext $ program_to_run "{file}"')
    except CommandNotFound as exception:
        print("Program from the rule not installed.")
        print(f"RULE: {exception.rule}")
    except KeyboardInterrupt:
        print("Command interrupted.")


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Default configuration for several filetypes.
"""
from pathlib import Path
from typing import Dict, Optional

from pydantic import BaseConfig, BaseModel, Field

from prettyfi.exceptions import UnknownRuleFormat

default_rules = {
    ".py": 'black "{file}" && isort "{file}"',
    ".toml": 'toml-sort --in-place "{file}"',
}

default_config_path = Path("~/.prettyfirc")


class SorterConfig(BaseModel):
    """
    Sorter settings
    """

    config: Path = Field(default_config_path)
    rules: Dict[str, str] = default_rules

    def get_rule(self, filename: str) -> Optional[str]:
        """
        Find rule by filename.
        """
        for pattern, rule in self.rules.items():
            if filename.endswith(pattern):
                return rule
        return None

    def startup_actions(self) -> None:
        if self.config == default_config_path and not self.config.expanduser().exists():
            with self.config.expanduser().open("w") as f:
                for pattern, rule in default_rules.items():
                    f.write(f"{pattern} $ {rule}\n")
        self.update_rules()

    def update_rules(self) -> None:
        """
        Parse and apply your custom rules to the config.
        """
        for index, line in enumerate(self.config.expanduser().open()):
            try:
                pattern, command = line.strip().split("$")
                self.rules[pattern.strip()] = command.strip()
            except ValueError:
                raise UnknownRuleFormat(index + 1, line.strip())

    class Config(BaseConfig):
        orm_mode = True



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Basic prettyfi exceptions.
"""


class UnknownRuleFormat(Exception):
    """
    Raised when one of the rules in config file has incorrect format
    """

    def __init__(self, line_num: int, line: str):
        """__init__.

        :param line_num: number of line with incorrect value
        :param line: line itself
        """
        super().__init__()
        self.line_num = line_num
        self.line = line


class CommandNotFound(Exception):
    """
    Raised when rule is applied but command from rule
    isn't found.
    """

    def __init__(self, rule: str):
        """__init__.

        :param rule: rule applied to file.
        """
        super().__init__()
        self.rule = rule



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['prettyfi']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.7.3,<2.0.0']

entry_points = \
{'console_scripts': ['prettyfi = prettyfi.main:main']}

setup_kwargs = {
    'name': 'prettyfi',
    'version': '0.1.5',
    'description': 'Simple tool to prettify your files',
    'long_description': '|py_versions| |build_statuses| |pypi_versions|\n\n.. |py_versions| image:: https://img.shields.io/pypi/pyversions/prettyfi?style=flat-square\n    :alt: python versions\n\n.. |build_statuses| image:: https://img.shields.io/github/workflow/status/s3rius/prettyfi/Testing%20and%20publish?style=flat-square\n    :alt: build status\n\n.. |pypi_versions| image:: https://img.shields.io/pypi/v/prettyfi?style=flat-square\n    :alt: pypi version\n    :target: https://pypi.org/project/prettyfi/\n\nPrettify your files with one command\n====================================\n\nPrettyfi usage\n**************\n\nusage: prettyfi [-h] [-c CONFIG] files [files ...]\n\nSimple utility to make your files prettier.\n\npositional arguments:\n  files                 Files to sort\n\noptional arguments:\n    --help                  show help message and exit\n    --config=config_path    path to configuration file\n\n.. code:: bash\n\n    prettyfi "prettyfi/main.py" "pyproject.toml" # Will make this files beautiful\n\nPrettyfi configuration\n**********************\n\nDefault config file location is "~/.prettyfirc".\n\nConfig file format:\n\n.. code:: bash\n\n    .<ext> $ pretty_command {file}\n    # Where "ext" -> your file extension,\n    # {file} -> stub for actual file,\n    # For example:\n    .py   $ isort {file}\n    .java $ rm {file}',
    'author': 'Pavel Kirilin',
    'author_email': 'win10@list.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/s3rius/prettyfi',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
